@@ -24,10 +24,10 @@ go mod download
 
 INSTALL_PKGS="golang.org/x/tools/cmd/goimports github.com/gogo/protobuf/protoc-gen-gogofast"
 for pkg in ${INSTALL_PKGS}; do
-    go install -mod=vendor "$pkg"
+    go install -mod=mod "$pkg"
 done
 
-GOGOPROTO_ROOT="$(go list -mod=readonly -f '{{ .Dir }}' -m github.com/gogo/protobuf)"
+GOGOPROTO_ROOT="$(go list -mod=mod -f '{{ .Dir }}' -m github.com/gogo/protobuf)"
 GOGOPROTO_PATH="${GOGOPROTO_ROOT}:${GOGOPROTO_ROOT}/protobuf"
 
 DIRS="nflog/nflogpb silence/silencepb cluster/clusterpb"
